
===============
Word Extraction
===============


Papers
======

* `基于文档主题结构的关键词抽取方法研究 <http://nlp.csai.tsinghua.edu.cn/~lzy/publications/phd_thesis.pdf>`_

Blogs
=====

* `关键词”提取都有哪些方案？ <https://www.zhihu.com/question/21104071>`_
* `TextRank算法提取关键词的Java实现 <http://www.hankcs.com/nlp/textrank-algorithm-to-extract-the-keywords-java-implementation.html>`_


Codes
=====

* `TextRank算法提取关键词的Java实现 <https://github.com/hankcs/TextRank>`_
* `TextRank4ZH <https://github.com/letiantian/TextRank4ZH>`_, TextRank python implementation


